@@ -1,7 +1,6 @@
 #' originr - Species Origin Data
 #'
-#' @importFrom stats na.omit setNames
-#' @importFrom httr GET content stop_for_status warn_for_status
+#' @importFrom crul HttpClient
 #' @importFrom jsonlite fromJSON
 #' @importFrom taxize get_uid classification get_tsn itis_native
 #' @importFrom xml2 read_xml xml_find_all xml_text
@@ -22,3 +21,24 @@
 #'  \item Integrated Taxonomic Information Service (http://www.itis.gov/)
 #' }
 NULL
+
+#' Vector of country names for use with NSR
+#'
+#' @format A vector of countries of length 251
+#' @name nsr_countries
+#' @docType data
+#' @keywords data
+NULL
+
+#' NSR political divisions
+#'
+#' @format A data frame with 73 rows and 2 variables:
+#' \describe{
+#'   \item{country}{Country name}
+#'   \item{state_province}{State or province name}
+#' }
+#' 
+#' @name nsr_pol_divisions
+#' @docType data
+#' @keywords data
+NULL
