@@ -4,8 +4,8 @@ test_that("gisd works", {
   skip_on_cran()
 
   sp <- c("Carpobrotus edulis", "Rosmarinus officinalis")
-  aa <- flora_europaea(sp[1], verbose = FALSE)
-  bb <- flora_europaea(sp[2], verbose = FALSE)
+  aa <- flora_europaea(sp[1], messages = FALSE)
+  bb <- flora_europaea(sp[2], messages = FALSE)
 
   expect_is(aa, "list")
   expect_named(aa, c('native', 'exotic', 'status_doubtful', 'occurrence_doubtful', 'extinct'))
@@ -22,6 +22,6 @@ test_that("fails well - species not found when searching GBIF", {
   skip_on_cran()
 
   sp <- "asdfadsf"
-  aa <- flora_europaea(sp, verbose = FALSE)
+  aa <- flora_europaea(sp, messages = FALSE)
   expect_null(aa)
 })
